@@ -23,19 +23,18 @@
 #ifndef MINUET_IPLUGIN_H
 #define MINUET_IPLUGIN_H
 
-#include "minuetinterfacesexport.h"
+#include <interfaces/minuetinterfacesexport.h>
 
 #include <QObject>
 
-namespace Minuet
-{
+namespace Minuet {
 
 class MINUETINTERFACES_EXPORT IPlugin : public QObject
 {
     Q_OBJECT
 
 public:
-    ~IPlugin() override;
+    virtual ~IPlugin() override;
 
 protected:
     explicit IPlugin(QObject *parent = 0);
